==> zio-aws-alexaforbusiness_2.12-5.17.104.7-sources.jar: zio/aws/alexaforbusiness/model/UpdateInstantBooking.scala <==
package zio.aws.alexaforbusiness.model
import java.lang.Integer
import zio.ZIO
import zio.aws.alexaforbusiness.model.primitives.Minutes
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class UpdateInstantBooking(
    durationInMinutes: Option[Minutes] = None,
    enabled: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking = {
    import UpdateInstantBooking.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
      .builder()
      .optionallyWith(
        durationInMinutes.map(value => Minutes.unwrap(value): Integer)
      )(_.durationInMinutes)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.UpdateInstantBooking.ReadOnly =
    zio.aws.alexaforbusiness.model.UpdateInstantBooking.wrap(buildAwsValue())
}
object UpdateInstantBooking {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.UpdateInstantBooking =
      zio.aws.alexaforbusiness.model.UpdateInstantBooking(
        durationInMinutes.map(value => value),
        enabled.map(value => value)
      )
    def durationInMinutes: Option[Minutes]
    def enabled: Option[Boolean]
    def getDurationInMinutes: ZIO[Any, AwsError, Minutes] =
      AwsError.unwrapOptionField("durationInMinutes", durationInMinutes)
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
  ) extends zio.aws.alexaforbusiness.model.UpdateInstantBooking.ReadOnly {
    override val durationInMinutes: Option[Minutes] = scala
      .Option(impl.durationInMinutes())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Minutes(value))
    override val enabled: Option[Boolean] =
      scala.Option(impl.enabled()).map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
  ): zio.aws.alexaforbusiness.model.UpdateInstantBooking.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-alexaforbusiness_2.12-5.17.178.1-sources.jar: zio/aws/alexaforbusiness/model/UpdateInstantBooking.scala <==
package zio.aws.alexaforbusiness.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.alexaforbusiness.model.primitives.Minutes
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class UpdateInstantBooking(
    durationInMinutes: Optional[Minutes] = Optional.Absent,
    enabled: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking = {
    import UpdateInstantBooking.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
      .builder()
      .optionallyWith(
        durationInMinutes.map(value => Minutes.unwrap(value): Integer)
      )(_.durationInMinutes)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly: zio.aws.alexaforbusiness.model.UpdateInstantBooking.ReadOnly =
    zio.aws.alexaforbusiness.model.UpdateInstantBooking.wrap(buildAwsValue())
}
object UpdateInstantBooking {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.alexaforbusiness.model.UpdateInstantBooking =
      zio.aws.alexaforbusiness.model.UpdateInstantBooking(
        durationInMinutes.map(value => value),
        enabled.map(value => value)
      )
    def durationInMinutes: Optional[Minutes]
    def enabled: Optional[Boolean]
    def getDurationInMinutes: ZIO[Any, AwsError, Minutes] =
      AwsError.unwrapOptionField("durationInMinutes", durationInMinutes)
    def getEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
  ) extends zio.aws.alexaforbusiness.model.UpdateInstantBooking.ReadOnly {
    override val durationInMinutes: Optional[Minutes] = zio.aws.core.internal
      .optionalFromNullable(impl.durationInMinutes())
      .map(value => zio.aws.alexaforbusiness.model.primitives.Minutes(value))
    override val enabled: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.enabled())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.alexaforbusiness.model.UpdateInstantBooking
  ): zio.aws.alexaforbusiness.model.UpdateInstantBooking.ReadOnly = new Wrapper(
    impl
  )
}
